@@ -22,12 +22,13 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
 #include <Lum/Label.h>
 #include <Lum/LED.h>
-#include <Lum/Menu.h>
 #include <Lum/Panel.h>
 #include <Lum/Table.h>
 #include <Lum/Text.h>
@@ -446,23 +447,34 @@ public:
 
     SetMain(horiz);
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
     menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(L"_Game")
-        ->AddMenuItemAction(L"_Choose collection",Lum::OS::qualifierControl,L"c",categoryAction)
-        ->AddMenuItemAction(L"Choose _level",Lum::OS::qualifierControl,L"l",levelAction)
-        ->AddMenuItemAction(L"Choose _theme",Lum::OS::qualifierControl,L"t",themeAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(L"_Restart level",Lum::OS::qualifierControl,L"r",restartAction)
-        ->AddMenuItemAction(L"_Undo step",Lum::OS::qualifierControl,L"u",restartAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->Group(L"Game")
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"Choose collection")
+                                  .SetShortcut(Lum::OS::qualifierControl,L"c"),
+                                  categoryAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"Choose level")
+                                  .SetShortcut(Lum::OS::qualifierControl,L"l"),
+                                  levelAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"Choose theme")
+                                  .SetShortcut(Lum::OS::qualifierControl,L"t"),
+                                  themeAction))
+        ->Separator()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"Restart level")
+                                  .SetShortcut(Lum::OS::qualifierControl,L"r"),
+                                  restartAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"Undo step")
+                                  .SetShortcut(Lum::OS::qualifierControl,L"u"),
+                                  undoAction))
+      ->End()
+      ->GroupHelp()
+        //->ActionHelp()
+        ->ActionAbout(aboutAction)
+      ->End();
 
     SetMenu(menu);
 
